#ifndef NT2_INCLUDE_CONSTANTS_HALFEPS_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_HALFEPS_HPP_INCLUDED

#include <nt2/constant/include/constants/halfeps.hpp>

#endif
